@@ -7,6 +7,7 @@
 import os
 import ssl
 import sys
+import time
 from typing import Any
 
 import urllib3  # type: ignore
@@ -35,6 +36,10 @@ def open_webdriver(
     verbose: bool = False,  # pylint: disable=unused-argument
 ) -> Driver:
     """Opens the web driver."""
+    if sys.platform == "linux":
+        if os.geteuid() == 0:
+            print("\n\n  WARNING: Running as root. The driver may crash!\n\n")
+            time.sleep(3)
     opts: Any = None
     if headless or FORCE_HEADLESS:
         if FORCE_HEADLESS and not headless:
@@ -54,7 +59,13 @@ def open_webdriver(
     driver_path = ChromeDriverManager(cache_valid_range=CACHE_TIMEOUT, path=WDM_DIR).install()
     if verbose:
         print(f"\n  Using ChromeDriver: {driver_path}")
-    return webdriver.Chrome(driver_path, options=opts, service_log_path=LOG_FILE)
+    try:
+        driver = webdriver.Chrome(driver_path, options=opts, service_log_path=LOG_FILE)
+        return driver
+    except Exception as err:  # pylint: disable=broad-except
+        print(f"{__file__}: Error: {err}")
+        print(f"Please see:\n  {LOG_FILE}")
+        raise
 
 
 if __name__ == "__main__":
